@@ -1,16 +1,18 @@
 import hashlib
 import json
 import logging
+import os
 import platform
 import sys
+import traceback
 from datetime import datetime
 from pathlib import Path
 from typing import Any, Dict
 
 import click
 import coloredlogs
+import pkg_resources
 import requests
-from click_plugins import with_plugins
 from packaging import version
 from pkg_resources import iter_entry_points
 from rich import box, print
@@ -20,6 +22,21 @@ from rich.table import Table
 from . import __version__
 
 
+class BrokenCommand(click.Command):
+    def __init__(self, name):
+
+        super().__init__(name)
+        util_name = os.path.basename(sys.argv and sys.argv[0] or __file__)
+        self.help = "\nEntrypoint could not be loaded \n\n\b\n" + traceback.format_exc()
+        self.short_help = (
+            f"CLI Plugin failed to load. See `{util_name} {self.name} --help"
+        )
+
+    def invoke(self, ctx):
+        click.echo(self.help, color=ctx.color)
+        ctx.exit(1)
+
+
 def _get_statefile_name(key):
     key_bytes = sys.prefix.encode("utf-8")
     name = hashlib.sha224(key_bytes).hexdigest()
@@ -85,7 +102,6 @@ class VersionCheck(object):
         return False, None
 
 
-@with_plugins(iter_entry_points("nomnomdata.cli_plugins"))
 @click.group()
 @click.version_option(version=__version__, prog_name="nomnomdata-cli")
 @click.option(
@@ -139,24 +155,38 @@ def main():
     info_table.add_column()
     for row in msg:
         info_table.add_row(*row)
-    outdated_table = Table(
-        "",
-        box=box.MINIMAL,
-        show_header=False,
-        pad_edge=True,
-        show_edge=False,
-    )
+
     outdated, new_version = check.check("nomnomdata-cli", __version__)
+    warnings = []
     if outdated:
-        outdated_plugins.append(
+        warnings.append(
             f"[bold yellow]nomnomdata-cli is outdated, latest version is {new_version}[/bold yellow]"
         )
-    for row in outdated_plugins:
-        outdated_table.add_row(row)
+    for entry_point in iter_entry_points("nomnomdata.cli_plugins"):
+        try:
+            cli.add_command(entry_point.load())
+        except (pkg_resources.VersionConflict, pkg_resources.DistributionNotFound) as e:
+            warnings.append(f"[bold red] {entry_point.dist}[/bold red]\t{e.report()}")
+            cli.add_command(BrokenCommand(entry_point.name))
+        except:
+            warnings.append(traceback.format_exc())
+            cli.add_command(BrokenCommand(entry_point.name))
     main_table = Table.grid()
     main_table.add_row(info_table)
-    main_table.add_row(outdated_table)
-    main_table
+
+    if warnings:
+        warning_table = Table(
+            "Issues",
+            box=box.MINIMAL,
+            show_header=True,
+            pad_edge=True,
+            show_edge=False,
+            expand=True,
+        )
+        for row in warnings:
+            warning_table.add_row(row)
+        main_table.add_row(warning_table)
+
     print(
         Panel(
             main_table,
